# Astrovision

The compulsory Python library to work with satellite imagery.

## Pre-requisites

`GDAL` must be installed.

## Installation

```bash
pip install astrovision
```

## Documentation

Documentation can be found here: https://inseefrlab.github.io/astrovision/.
